@@ -35,7 +35,4 @@ link_files = {
 # Be strict about any broken references:
 nitpicky = True
 
-# Custom sidebar templates, maps document names to template names.
-html_theme = 'alabaster'
-templates_path = ['_templates']
-html_sidebars = {'index': ['tidelift-sidebar.html']}
+extensions += ['jaraco.tidelift']
